=======
History
=======

0.0.1 (2019-01-24)
------------------

* First release on PyPI.

0.0.4 (2019-04-26)
------------------

* Updated syntax for binblockread to mimic that of PyVISA. Created documentation.

2020.04.0 (2020-04-15)
----------------------

* Added a .read() method. Wrote test scripts to verify performance. Overhauled documentation. Switched to calendar-style versioning.
